==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/StoredClassInformation.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o.ext;
namespace com.db4o.test {

   public class StoredClassInformation {
      
      public StoredClassInformation() : base() {
      }
      static internal int COUNT = 10;
      public String name;
      
      public void test() {
         Tester.deleteAllInstances(this);
         name = "hi";
         Tester.store(this);
         for (int i1 = 0; i1 < COUNT; i1++) {
            Tester.store(new StoredClassInformation());
         }
         StoredClass[] storedClasses1 = Tester.objectContainer().ext().storedClasses();
         StoredClass myClass1 = Tester.objectContainer().ext().storedClass(this);
         bool found1 = false;
         for (int i1 = 0; i1 < storedClasses1.Length; i1++) {
            if (storedClasses1[i1].getName().Equals(myClass1.getName())) {
               found1 = true;
               break;
            }
         }
         Tester.ensure(found1);
         long id1 = Tester.objectContainer().getID(this);
         long[] ids1 = myClass1.getIDs();
         Tester.ensure(ids1.Length == COUNT + 1);
         found1 = false;
         for (int i1 = 0; i1 < ids1.Length; i1++) {
            if (ids1[i1] == id1) {
               found1 = true;
               break;
            }
         }
         Tester.ensure(found1);
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/StoredClassInformation.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o.ext;
namespace com.db4o.test {

   public class StoredClassInformation {
      
      public StoredClassInformation() : base() {
      }
      static internal int COUNT = 10;
      public String name;
      
      public void Test() {
         Tester.DeleteAllInstances(this);
         name = "hi";
         Tester.Store(this);
         for (int i1 = 0; i1 < COUNT; i1++) {
            Tester.Store(new StoredClassInformation());
         }
         StoredClass[] storedClasses1 = Tester.ObjectContainer().Ext().StoredClasses();
         StoredClass myClass1 = Tester.ObjectContainer().Ext().StoredClass(this);
         bool found1 = false;
         for (int i1 = 0; i1 < storedClasses1.Length; i1++) {
            if (storedClasses1[i1].GetName().Equals(myClass1.GetName())) {
               found1 = true;
               break;
            }
         }
         Tester.Ensure(found1);
         long id1 = Tester.ObjectContainer().GetID(this);
         long[] ids1 = myClass1.GetIDs();
         Tester.Ensure(ids1.Length == COUNT + 1);
         found1 = false;
         for (int i1 = 0; i1 < ids1.Length; i1++) {
            if (ids1[i1] == id1) {
               found1 = true;
               break;
            }
         }
         Tester.Ensure(found1);
      }
   }
}
